@@ -702,7 +702,7 @@ class BaseEnvironnement(BaseEstimator):
         >>>         # liaison des poids
         >>>         self.dense1.weight = self.dense2.weigth
         >>>
-        >>>     def post_move_to_tup(self):
+        >>>     def post_move_to_tpu(self):
         >>>         self.dense1.weight = self.dense2.weigth
         [...]
 
@@ -809,8 +809,8 @@ class BaseEnvironnement(BaseEstimator):
                 max_gradient_norm=max_gradient_norm
             )
         self.to(control.device)
-        if control.device.type != "tpu" and hasattr(self, 'post_move_to_tup'):
-            self.post_move_to_tup()
+        if control.device.type != "tpu" and hasattr(self, 'post_move_to_tpu'):
+            self.post_move_to_tpu()
         if isinstance(loss_fn, FunctionType):
             co_varnames = loss_fn.__code__.co_varnames
         elif isinstance(loss_fn, partial):
