@@ -488,7 +488,7 @@ def apply_metric_error(fun: Callable,
     score : float
         score issu de fun ou inf.
     """
-    if all(~np.isnan(y_pred)) and all(~np.isinf(y_pred)):
+    if all(~np.isnan(y_pred).ravel()) and all(~np.isinf(y_pred).ravel()):
         return fun(y_true, y_pred, **kargs)
     else:
         return np.inf
